
oujago
======


Coding makes the life easier. This is a factory contains commonly used
algorithms and useful links.


API References
==============

.. toctree::
    :maxdepth: 2

    api_references/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`



